An omnet++-like simulation framework fully implemented on Python, with the possibility to support different simulation backends such as SimPy.

Visit the tutorial and documentation page [here](https://lbacciottini.github.io/OmnetPyPy/).
